Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2013-11-09 15:22:44 +0000
committerStijn Buys <ingar@osirion.org>2013-11-09 15:22:44 +0000
commit977a9a68d2465818a331643399a9ecc998d0cbb3 (patch)
tree5e19904a95119ebc22cfffedcf4bd7b2094e4e31 /src/core/netserver.h
parentd0b6e591fbaf3db5fc9898e75913e57a3c32169a (diff)
Bumped network protocol to version 27,
send player reputation and stats from server to client, send entity faction to clients, improved list_entity.
Diffstat (limited to 'src/core/netserver.h')
-rw-r--r--src/core/netserver.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/core/netserver.h b/src/core/netserver.h
index a739e28..7277866 100644
--- a/src/core/netserver.h
+++ b/src/core/netserver.h
@@ -93,9 +93,12 @@ protected:
/// send an update player information message
void send_player_update(NetClient *client);
- /// send an general update player information message
- void send_player_update(NetClient *client, Player *player);
+ /// send an update player reputation message
+ void send_player_reputation(NetClient *client);
+ /// send a general update player information message
+ void send_player_update(NetClient *client, Player *player);
+
/// send player disconnect information message
void send_player_disconnect_info(NetClient *client, Player *player);